<?php
/**
 * @file
 * Definition of PluginParser
 */

class PluginParser {

  /**
   * Display html for dialog form parameters.
   *
   * @param string $plugin
   *   name of template file
   */
  public function displayForm($plugin) {
    $fields = $this->parseValues($plugin);
    $tidy_ups = array();
    $disabled_fields = array();
    print "<script type=\"text/javascript\">tidyUps={};</script>\n";
    print "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\" border=\"0\">\n";
    $cnt = 0;
    foreach ($fields as $settings) {
      print '<tr' . (!empty($settings['disabled']) ? ' style="display: none;"' : '') . '>';
      print '<th' . (!$cnt ? ' width="40%"' : '') . '>' . htmlspecialchars($settings['label']) . '</th>';
      print '<td' . (!$cnt ? ' width="60%"' : '') . '>';
      switch ($settings['type']) {
        case 'dropdown':
        case 'select':
          print '<select name="field[]" id="t_field_' . $settings['index'] . '" order="' . $settings['index'] . '">';
          foreach ($settings['options'] as $key => $val) {
            print '<option value="' . htmlentities($key) . '">' . htmlspecialchars($val) . '</option>';
          }
          print '</select>';
          break;

        case 'textbox':
        default:
          print '<input type="text" name="field[]" id="t_field_' . $settings['index'] . '" order="' . $settings['index'] . '" value="" size="' . (!empty($settings['size']) && is_numeric($settings['size']) ? (int) $settings['size'] : 40) . '"' . (!empty($settings['regex']) ? ' onblur="if(!' . $settings['regex'] . '.test(this.value)) { alert(\'Please check your value for the \\\'' . addslashes($field) . '\\\' field.\'); this.focus(); return false; }"' : '') . ' />';
          break;
      }
      print '</td></tr>';
      if (!empty($settings['tidy-ups']) && is_array($settings['tidy-ups'])) {
        $tidy_ups[$settings['index']] = $settings['tidy-ups'];
      }
      $cnt++;
    }
    print '</table>';
    print '<script type="text/javascript">tidyUps=' . json_encode($tidy_ups) . '; disabledFields=' . json_encode($disabled_fields) . ";</script>\n";
  }

  /**
   * Get parameter values from template file.
   *
   * @param string $plugin
   *   Name of template file
   *
   * @return array
   *   Template fields
   */
  protected function parseValues($plugin) {
    $template_path = drupal_get_path('module', 'fck_content_injector') . '/injector_templates';
    $get_form_elements = TRUE;
    ob_start();
    require $template_path . '/' . basename($plugin);
    ob_end_clean();
    $fields = array();
    // Set weight ordering and field position.
    if (!empty($params) && is_array($params)) {
      $tmp = array();
      $index = 0;
      foreach ($params as $label => $field) {
        // Get field weight.
        $weight = (!empty($field['weight'])) ? $field['weight'] : 0;
        // Ensure temporary weight array exists.
        if (empty($tmp[$weight])) {
          $tmp[$weight] = array();
        }
        // Add additional field values.
        $field['label'] = $label;
        $field['index'] = $index;
        // Build temporary weight orders array.
        $tmp[$weight][] = $field;
        // Increment field index counter.
        $index++;
      }
      // Order tmp array by weight key.
      ksort($tmp);
      // Build field array ordered by weight.
      foreach ($tmp as $w_fields) {
        foreach ($w_fields as $f) {
          $fields[] = $f;
        }
      }
    }
    return $fields;
  }
}
